# Nagios Development Kit

NDK is a software development framework for defining Nagios Object in code and deploy it to your Nagios.

Use the NDK to define your resources you want monitor to.

## Quick Start

### Example

```
python example.py
```

### Testing

```
pytest
```
